==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-VE/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorios',
    'activated'			    => 'Activado',
    'accessory'				=> 'Accesorio',
    'accessory_report'		=> 'Reporte de Accesorio',
    'action'                => 'Acción',
    'activity_report'		=> 'Reporte de Actividad',
    'address'				=> 'Dirección',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrador',
    'add_seats'             => 'Puestos añadidos',
    'all_assets'			=> 'Todos los Activos',
    'all'       			=> 'Todo',
    'archived'              => 'Archivado',
    'asset_models'			=> 'Modelos de Activos',
    'asset_model'			=> 'Modelo',
    'asset'					=> 'Activo',
    'asset_report'          => 'Reporte de Activo',
    'asset_tag'				=> 'Etiqueta de Activo',
    'assets_available'		=> 'activos disponibles',
    'audit'				    => 'Auditar',
    'audit_report'			=> 'Registro de Auditoría',
    'assets'				=> 'Activos',
    'avatar_delete'         => 'Borrar Avatar',
    'avatar_upload'         => 'Cargar Avatar',
    'back'      			=> 'Atrás',
    'bad_data'      		=> 'No se ha encontrado nada. ¿Quizás datos incorrectos?',
    'bulkaudit'             => 'Auditoría Masiva',
    'bulkaudit_status'      => 'Auditar Estado',
    'bulk_checkout'  		=> 'Asignación Masiva',
    'bystatus'              => 'por Estado',
    'cancel'  				=> 'Cancelar',
    'categories'			=> 'Categorías',
    'category'				=> 'Categoría',
    'change' 		        => 'Entrada/Salida',
    'changeemail'  			=> 'Cambiar Dirección de Correo Electrónico',
    'changepassword'  		=> 'Cambiar Contraseña',
    'checkin'  				=> 'Registrar',
    'checkin_from'  		=> 'Registrar desde',
    'checkout'  			=> 'Asignar',
    'checkouts_count'       => 'Dar de Baja',
    'checkins_count'        => 'Dar de Alta',
    'user_requests_count'   => 'Solicitudes',
    'city'  				=> 'Ciudad',
	'click_here'			=> 'Click aquí',
    'clear_selection'		=> 'Limpiar selección',
    'companies'			    => 'Compañías',
    'company'				=> 'Compañía',
    'component'			    => 'Componente',
    'components'			=> 'Componentes',
	'complete'				=> 'Completo',
    'consumable'			=> 'Consumible',
    'consumables'			=> 'Consumibles',
    'country'  				=> 'País',
    'create'				=> 'Crear Nuevo',
    'created'               => 'Elemento Creado',
    'created_asset'			=> 'activo creado',
    'created_at' 			=> 'Creado El',
    'record_created' 		=> 'Registro Creado',
    'updated_at' 			=> 'Actualizado El',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Actual',
    'custom_report'         => 'Reporte de Activos Personalizados',
    'dashboard'				=> 'Tablero',
    'days'      			=> 'días',
    'days_to_next_audit'    => 'Días para la Próxima Auditoría',
    'date'					=> 'Fecha',
    'debug_warning'         => '¡Advertencia!',
    'debug_warning_text'    => 'Esta aplicación se está ejecutando en modo producción con el depurador activado. Esto puede exponer datos sensibles si tu aplicación es accesible al exterior. Desactiva el modo de depuración mediante la configuración del valor <code>APP_DEBUG</code> en tu archivo <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'Borrar',
    'delete_confirm'  		=> '¿Estás seguro de eliminar :item?',
    'deleted'  				=> 'Borrado',
    'delete_seats'  		=> 'Puestos Borrados',
    'departments'           => 'Departamentos',
    'department'           => 'Departamento',
    'deployed'				=> 'Desplegado',
    'depreciation_report'	=> 'Reporte de Depreciación',
    'details'               => 'Detalles',
    'download'				=> 'Descarga',
    'download_all'				=> 'Descargar todo',
    'depreciation'			=> 'Depreciación',
    'editprofile'  			=> 'Editar tu Perfil',
    'eol'					=> 'Fin de Vida',
    'email_domain'			=> 'Dominio de Correo Electrónico',
    'email_format'			=> 'Formato de Correo Electrónico',
    'email_domain_help'		=> 'Este se utiliza para generar direcciones de correo al importar',
    'filastname_format'			=> 'Primera Inicial y Apellido (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nombre y Apellido (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Primer Nombre y Apellido (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Apellido First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'first'					=> 'Primer',
    'firstnamelastname'     => 'Nombre Apellido (jane.smith@ejemplo.com)',
    'lastname_firstinitial' => 'Apellido Inicial (smith_j@ejemplo.com)',
    'firstinitial.lastname' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nombre',
    'first_name_format'		=> 'Primer Nombre (jane@ejemplo.com)',
    'files'                 => 'Archivos',
    'file_name'				=> 'Archivo',
    'file_type'             => 'Tipo de archivo',
    'file_uploads'			=> 'Carga de Archivos',
    'generate'				=> 'Generar',
     'github_markdown'      => 'Este campo acepta el <a href="https://help.github.com/articles/github-flavored-markdown/">formateo estilo GitHub</a>.',
    'groups'				=> 'Grupos',
    'gravatar_email'        => 'Dirección de Correo Gravatar',
    'history'  			    => 'Historial',
    'history_for'  			=> 'Historial para',
    'id'  					=> 'ID',
    'image'                 => 'Imagen',
    'image_delete'         	=> 'Borrar Imagen',
    'image_upload'         	=> 'Subir Imagen',
    'image_filetypes_help'  => 'Los tipos de archivo aceptados son jpg, webp, png, gif y svg. El tamaño máximo permitido es :size.',
    'import'         	    => 'Importar',
    'importing'         	=> 'Importando',
    'importing_help'        => 'Puedes importar activos, accesorios, licencias, componentes, insumos y usuarios vía archivos CSV.<br> <br> El CSV debe estar delimitado por comas y formateado con encabezados que coincidan con aquellos definidos en los <a href="https://snipe-it.readme.io/docs/importing" target="_new"> CSVs de muestra en la documentación</a>.',
    'import-history'        => 'Importar Historial',
    'asset_maintenance'        => 'Mantenimiento de Activos',
    'asset_maintenance_report' => 'Reporte de Mantenimiento de Activo',
    'asset_maintenances'       => 'Mantenimientos de Activo',
    'item'  				=> 'Elemento',
    'insufficient_permissions' => '¡Permisos insuficientes!',
    'kits'       			=> 'Equipamiento predefinido',
    'language'				=> 'Lenguaje',
    'last'					=> 'Último',
    'last_login'            => 'Último Inicio de Sesión',
    'last_name'             => 'Apellido',
    'license'				=> 'Licencia',
    'license_report'        => 'Reporte de Licencias',
    'licenses_available'	=> 'licencias disponibles',
    'licenses'				=> 'Licencias',
    'list_all'				=> 'Listar Todo',
    'loading'				=> 'Cargando',
    'lock_passwords'        => 'El valor de este campo no será guardado en una instalación de demostración.',
    'feature_disabled'      => 'Esta característica ha sido deshabilitada para la instalación demo.',
    'location'              => 'Ubicación',
    'locations'				=> 'Ubicaciones',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Cerrar sesión',
    'lookup_by_tag'     => 'Buscar por etiqueta del activo',
    'maintenances'          => 'Mantenimientos',
    'manufacturer'			=> 'Fabricante',
    'manufacturers'			=> 'Fabricantes',
    'markdown'				=> 'Este campo permite <a href="https://help.github.com/articles/github-flavored-markdown/">formateo estilo Github</a>.',
    'min_amt'				=> 'Cantidad Mínima',
    'min_amt_help'	=> 'Mínimo número de elementos que deben estar disponibles antes de que las ofertas sean activadas.',
    'model_no'				=> 'Modelo nú.',
    'months'				=> 'meses',
    'moreinfo'				=> 'Más Información',
    'name'					=> 'Nombre',
    'next'					=> 'Siguiente',
    'next_audit_date'		=> 'Próxima fecha de auditoría',
    'last_audit'		    => 'Última auditoría',
    'new'					=> '¡nuevo!',
    'no_depreciation'		=> 'Sin Depreciación',
    'no_results'			=> 'Sin Resultados.',
    'no'  					=> 'No',
    'notes'  				=> 'Notas',
    'order_number'          => 'Número de Orden',
    'page_menu'				=> 'Mostrando elementos de _MENU_',
    'pagination_info'		=> 'Mostrando _START_ de _END_ de elementos _TOTAL_',
    'pending'				=> 'Pendiente',
    'people'				=> 'Usuarios',
    'per_page'				=> 'Resultados Por Página',
    'previous'				=> 'Anterior',
    'processing'			=> 'Procesando',
    'profile'				=> 'Tu Perfil',
    'purchase_cost'                              => 'Costo de Compra',
    'purchase_date'         => 'Fecha de Compra',
    'qty'		            => 'Cantidad',
    'quantity'		        => 'Cantidad',
    'ready_to_deploy'		=> 'Listo para enviar',
    'recent_activity'		=> 'Actividad Reciente',
    'remove_company'        => 'Eliminar Asociación de la Compañía',
    'reports'				=> 'Reportes',
    'restored'				=> 'restaurado',
    'requested'				=> 'Solicitado',
    'request_canceled'      => 'Solicitud Cancelada',
    'save'  				=> 'Guardar',
    'select'				=> 'Seleccionar',
    'search'				=> 'Buscar',
    'select_category'       => 'Seleccionar una categoría',
    'select_department'       => 'Seleccionar un Departamento',
    'select_depreciation'	=> 'Seleccionar un Tipo de Depreciación',
    'select_location'		=> 'Seleccionar una Ubicación',
    'select_manufacturer'	=> 'Seleccionar un Fabricante',
    'select_model'			=> 'Seleccionar un Modelo',
    'select_supplier'		=> 'Selecciona un Proveedor',
    'select_user'			=> 'Selecciona un Usuario',
    'select_date'			=> 'Seleccione Fecha (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Seleccione Estado',
    'select_company'    	=> 'Seleccione Compañía',
    'select_asset'    		=> 'Seleccione Activo',
    'settings'				=> 'Configuraciones',
    'show_deleted'  		=> 'Mostrar Eliminado',
    'show_current'  		=> 'Mostrar actual',
    'sign_in'				=> 'Entrar',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_test_msg'        => '¡Parece que tu integración de Slack con Snipe-IT está funcionando!',
    'some_features_disabled' => 'MODO DEMO: Algunas funciones están desactivadas para esta instalación.',
    'site_name'				=> 'Nombre del Sitio',
    'state'  				=> 'Estado',
    'status_labels'			=> 'Etiquetas de Estado',
    'status'    			=> 'Estado',
    'supplier'              => 'Proveedor',
    'suppliers'  			=> 'Proveedores',
    'sure_to_delete'    => '¿Está seguro que quieres borrar',
    'submit'				=> 'Enviar',
    'target'                => 'Objetivo',
    'time_and_date_display' => 'Visualización de Hora y Fecha',
    'total_assets'			=> 'total de activos',
    'total_licenses'		=> 'licencias totales',
    'total_accessories'		=> 'accesorios totales',
    'total_consumables'		=> 'total de consumibles',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'No desplegable',
    'unknown_admin'			=> 'Administrador Desconocido',
    'username_format'		=> 'Formato de Nombre de Usuario',
    'update'                => 'Actualizar',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Actualizado',
    'user'					=> 'Usuario',
    'accepted'			    => 'aceptado',
    'declined'			    => 'rechazado',
    'unaccepted_asset_report' => 'Activos no aceptados',
    'users'                 => 'Usuarios',
    'viewall'				=> 'Ver todos',
    'viewassets'  			=> 'Ver Activos Asignados',
    'website'               => 'Sitio Web',
    'welcome'				=> 'Bienvenido, :name',
    'years'					=> 'años',
    'yes' 					=> 'Si',
    'zip'  					=> 'Códio Postal',
    'noimage'				=> 'No se subió la imagen o no fue encontrada.',
    'token_expired'         => 'Tu sesión ha expirado. Por favor inténtalo de nuevo.',
    'login_enabled'         => 'Inicio de sesión habilitado',
    'audit_due'             => 'Auditoría pendiente',
    'audit_overdue'         => 'Auditoría retrasada',
    'accept'                => 'Aceptar :asset',
    'i_accept'              => 'Acepto',
    'i_decline'             => 'Rechazo',
    'sign_tos'              => 'Firma abajo para indicar que estás de acuerdo con los términos de servicio:',
    'clear_signature'       => 'Borrar firma',
    'show_help'             => 'Mostrar ayuda',
    'hide_help'             => 'Ocultar ayuda',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorios',
    'activated'			    => 'Activado',
    'accessory'				=> 'Accesorio',
    'accessory_report'		=> 'Reporte de Accesorio',
    'action'                => 'Acción',
    'activity_report'		=> 'Reporte de Actividad',
    'address'				=> 'Dirección',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrador',
    'add_seats'             => 'Puestos añadidos',
    'all_assets'			=> 'Todos los Activos',
    'all'       			=> 'Todo',
    'archived'              => 'Archivado',
    'asset_models'			=> 'Modelos de Activos',
    'asset_model'			=> 'Modelo',
    'asset'					=> 'Activo',
    'asset_report'          => 'Reporte de Activo',
    'asset_tag'				=> 'Etiqueta de Activo',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Equipos disponibles',
    'accept_assets'         => 'Activos Aceptados :name',
    'accept_assets_menu'    => 'Activos Aceptados',
    'audit'				    => 'Auditar',
    'audit_report'			=> 'Registro de Auditoría',
    'assets'				=> 'Activos',
    'avatar_delete'         => 'Borrar Avatar',
    'avatar_upload'         => 'Cargar Avatar',
    'back'      			=> 'Atrás',
    'bad_data'      		=> 'No se ha encontrado nada. ¿Quizás datos incorrectos?',
    'bulkaudit'             => 'Auditoría Masiva',
    'bulkaudit_status'      => 'Auditar Estado',
    'bulk_checkout'  		=> 'Asignación Masiva',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'por Estado',
    'cancel'  				=> 'Cancelar',
    'categories'			=> 'Categorías',
    'category'				=> 'Categoría',
    'change' 		        => 'Entrada/Salida',
    'changeemail'  			=> 'Cambiar Dirección de Correo Electrónico',
    'changepassword'  		=> 'Cambiar Contraseña',
    'checkin'  				=> 'Registrar',
    'checkin_from'  		=> 'Registrar desde',
    'checkout'  			=> 'Asignar',
    'checkouts_count'       => 'Dar de Baja',
    'checkins_count'        => 'Dar de Alta',
    'user_requests_count'   => 'Solicitudes',
    'city'  				=> 'Ciudad',
    'click_here'			=> 'Click aquí',
    'clear_selection'		=> 'Limpiar selección',
    'companies'			    => 'Compañías',
    'company'				=> 'Compañía',
    'component'			    => 'Componente',
    'components'			=> 'Componentes',
    'complete'				=> 'Completo',
    'consumable'			=> 'Consumible',
    'consumables'			=> 'Consumibles',
    'country'  				=> 'País',
    'create'				=> 'Crear Nuevo',
    'created'               => 'Elemento Creado',
    'created_asset'			=> 'activo creado',
    'created_at' 			=> 'Creado El',
    'record_created' 		=> 'Registro Creado',
    'updated_at' 			=> 'Actualizado El',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Actual',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Reporte de Activos Personalizados',
    'dashboard'				=> 'Tablero',
    'days'      			=> 'días',
    'days_to_next_audit'    => 'Días para la Próxima Auditoría',
    'date'					=> 'Fecha',
    'debug_warning'         => '¡Advertencia!',
    'debug_warning_text'    => 'Esta aplicación se está ejecutando en modo producción con el depurador activado. Esto puede exponer datos sensibles si tu aplicación es accesible al exterior. Desactiva el modo de depuración mediante la configuración del valor <code>APP_DEBUG</code> en tu archivo <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'Borrar',
    'delete_confirm'  		=> '¿Estás seguro de eliminar :item?',
    'deleted'  				=> 'Borrado',
    'delete_seats'  		=> 'Puestos Borrados',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Departamentos',
    'department'            => 'Departamento',
    'deployed'				=> 'Desplegado',
    'depreciation'			=> 'Depreciación',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Reporte de Depreciación',
    'details'               => 'Detalles',
    'download'				=> 'Descarga',
    'download_all'		    => 'Descargar todo',
    'editprofile'  			=> 'Editar tu Perfil',
    'eol'					=> 'Fin de Vida',
    'email_domain'			=> 'Dominio de Correo Electrónico',
    'email_format'			=> 'Formato de Correo Electrónico',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Este se utiliza para generar direcciones de correo al importar',
    'error'				    => 'Error',
    'filastname_format'			=> 'Primera Inicial y Apellido (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nombre y Apellido (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Primer Nombre y Apellido (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Apellido First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'first'					=> 'Primer',
    'firstnamelastname'     => 'Nombre Apellido (jane.smith@ejemplo.com)',
    'lastname_firstinitial' => 'Apellido Inicial (smith_j@ejemplo.com)',
    'firstinitial.lastname' => 'Inicial Apellido (j.smith@ejemplo.com)',
    'firstnamelastinitial'  => 'Primer nombre y última inicial (janes@example.com)',
    'first_name'			=> 'Nombre',
    'first_name_format'		=> 'Primer Nombre (jane@ejemplo.com)',
    'files'                 => 'Archivos',
    'file_name'				=> 'Archivo',
    'file_type'             => 'Tipo de archivo',
    'file_uploads'			=> 'Carga de Archivos',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Generar',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'Este campo acepta el <a href="https://help.github.com/articles/github-flavored-markdown/">formateo estilo GitHub</a>.',
    'groups'				=> 'Grupos',
    'gravatar_email'        => 'Dirección de Correo Gravatar',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Historial',
    'history_for'  			=> 'Historial para',
    'id'  					=> 'ID',
    'image'                 => 'Imagen',
    'image_delete'         	=> 'Borrar Imagen',
    'image_upload'         	=> 'Subir Imagen',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Los tipos de archivo aceptados son jpg, webp, png, gif y svg. El tamaño máximo permitido es :size.',
    'import'         	    => 'Importar',
    'importing'         	=> 'Importando',
    'importing_help'        => 'Puedes importar activos, accesorios, licencias, componentes, insumos y usuarios vía archivos CSV.<br> <br> El CSV debe estar delimitado por comas y formateado con encabezados que coincidan con aquellos definidos en los <a href="https://snipe-it.readme.io/docs/importing" target="_new"> CSVs de muestra en la documentación</a>.',
    'import-history'        => 'Importar Historial',
    'asset_maintenance'        => 'Mantenimiento de Activos',
    'asset_maintenance_report' => 'Reporte de Mantenimiento de Activo',
    'asset_maintenances'       => 'Mantenimientos de Activo',
    'item'  				=> 'Elemento',
    'item_name'             => 'Nombre del ítem',
    'insufficient_permissions' => '¡Permisos insuficientes!',
    'kits'       			=> 'Equipamiento predefinido',
    'language'				=> 'Lenguaje',
    'last'					=> 'Último',
    'last_login'            => 'Último Inicio de Sesión',
    'last_name'             => 'Apellido',
    'license'				=> 'Licencia',
    'license_report'        => 'Reporte de Licencias',
    'licenses_available'	=> 'licencias disponibles',
    'licenses'				=> 'Licencias',
    'list_all'				=> 'Listar Todo',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'El valor de este campo no será guardado en una instalación de demostración.',
    'feature_disabled'      => 'Esta característica ha sido deshabilitada para la instalación demo.',
    'location'              => 'Ubicación',
    'locations'				=> 'Ubicaciones',
    'logo_size'				=> 'Los logotipos cuadrados se ven mejor con Logo + Texto. El tamaño máximo del logo es 50px de altura x 500px de ancho.  ',
    'logout'				=> 'Cerrar sesión',
    'lookup_by_tag'     => 'Buscar por etiqueta del activo',
    'maintenances'          => 'Mantenimientos',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Fabricante',
    'manufacturers'			=> 'Fabricantes',
    'markdown'				=> 'Este campo permite <a href="https://help.github.com/articles/github-flavored-markdown/">formateo estilo Github</a>.',
    'min_amt'				=> 'Cantidad Mínima',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Modelo nú.',
    'months'				=> 'meses',
    'moreinfo'				=> 'Más Información',
    'name'					=> 'Nombre',
    'new_password'          => 'New Password',
    'next'					=> 'Siguiente',
    'next_audit_date'		=> 'Próxima fecha de auditoría',
    'last_audit'		    => 'Última auditoría',
    'new'					=> '¡nuevo!',
    'no_depreciation'		=> 'Sin Depreciación',
    'no_results'			=> 'Sin Resultados.',
    'no'  					=> 'No',
    'notes'  				=> 'Notas',
    'order_number'          => 'Número de Orden',
    'page_menu'				=> 'Mostrando elementos de _MENU_',
    'pagination_info'		=> 'Mostrando _START_ de _END_ de elementos _TOTAL_',
    'pending'				=> 'Pendiente',
    'people'				=> 'Usuarios',
    'per_page'				=> 'Resultados Por Página',
    'previous'				=> 'Anterior',
    'processing'			=> 'Procesando',
    'profile'				=> 'Tu Perfil',
    'purchase_cost'                              => 'Costo de Compra',
    'purchase_date'         => 'Fecha de Compra',
    'qty'		            => 'Cantidad',
    'quantity'		        => 'Cantidad',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Listo para enviar',
    'recent_activity'		=> 'Actividad Reciente',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Eliminar Asociación de la Compañía',
    'reports'				=> 'Reportes',
    'restored'				=> 'restaurado',
    'restore'				=> 'Restaurar',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Solicitado',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Solicitud Cancelada',
    'save'  				=> 'Guardar',
    'select'				=> 'Seleccionar',
    'select_all'            => 'Select All',
    'search'				=> 'Buscar',
    'select_category'       => 'Seleccionar una categoría',
    'select_department'     => 'Seleccionar un Departamento',
    'select_depreciation'	=> 'Seleccionar un Tipo de Depreciación',
    'select_location'		=> 'Seleccionar una Ubicación',
    'select_manufacturer'	=> 'Seleccionar un Fabricante',
    'select_model'			=> 'Seleccionar un Modelo',
    'select_supplier'		=> 'Selecciona un Proveedor',
    'select_user'			=> 'Selecciona un Usuario',
    'select_date'			=> 'Seleccione Fecha (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Seleccione Estado',
    'select_company'    	=> 'Seleccione Compañía',
    'select_asset'    		=> 'Seleccione Activo',
    'settings'				=> 'Configuraciones',
    'show_deleted'  		=> 'Mostrar Eliminado',
    'show_current'  		=> 'Mostrar actual',
    'sign_in'				=> 'Entrar',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => '¡Parece que tu integración de Slack con Snipe-IT está funcionando!',
    'some_features_disabled' => 'MODO DEMO: Algunas funciones están desactivadas para esta instalación.',
    'site_name'				=> 'Nombre del Sitio',
    'state'  				=> 'Estado',
    'status_labels'			=> 'Etiquetas de Estado',
    'status'    			=> 'Estado',
    'supplier'              => 'Proveedor',
    'suppliers'  			=> 'Proveedores',
    'sure_to_delete'    => '¿Está seguro que quieres borrar',
    'submit'				=> 'Enviar',
    'target'                => 'Objetivo',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Visualización de Hora y Fecha',
    'total_assets'			=> 'total de activos',
    'total_licenses'		=> 'licencias totales',
    'total_accessories'		=> 'accesorios totales',
    'total_consumables'		=> 'total de consumibles',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'No desplegable',
    'unknown_admin'			=> 'Administrador Desconocido',
    'username_format'		=> 'Formato de Nombre de Usuario',
    'update'                => 'Actualizar',
    'upload_filetypes_help'      => 'Los tipos de archivo permitidos son png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf y rar. El tamaño máximo permitido es :size.',
    'uploaded'              => 'Actualizado',
    'user'					=> 'Usuario',
    'accepted'			    => 'aceptado',
    'declined'			    => 'rechazado',
    'unaccepted_asset_report' => 'Activos no aceptados',
    'users'                 => 'Usuarios',
    'viewall'				=> 'Ver todos',
    'viewassets'  			=> 'Ver Activos Asignados',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Sitio Web',
    'welcome'				=> 'Bienvenido, :name',
    'years'					=> 'años',
    'yes' 					=> 'Si',
    'zip'  					=> 'Códio Postal',
    'noimage'				=> 'No se subió la imagen o no fue encontrada.',
    'token_expired'         => 'Tu sesión ha expirado. Por favor inténtalo de nuevo.',
    'login_enabled'         => 'Inicio de sesión habilitado',
    'audit_due'             => 'Auditoría pendiente',
    'audit_overdue'         => 'Auditoría retrasada',
    'accept'                => 'Aceptar :asset',
    'i_accept'              => 'Acepto',
    'i_decline'             => 'Rechazo',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Firma abajo para indicar que estás de acuerdo con los términos de servicio:',
    'clear_signature'       => 'Borrar firma',
    'show_help'             => 'Mostrar ayuda',
    'hide_help'             => 'Ocultar ayuda',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
